[jboss-svn-commits] JBL Code SVN: r24185 - in labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer: metadata and 1 other directory.

jboss-svn-commits at lists.jboss.org jboss-svn-commits at lists.jboss.org
Mon Dec 1 10:43:15 EST 2008


Author: beve
Date: 2008-12-01 10:43:15 -0500 (Mon, 01 Dec 2008)
New Revision: 24185

Modified:
   labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/deployers/EsbDeployment.java
   labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/metadata/EsbMetaData.java
Log:
Minor refactoring.


Modified: labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/deployers/EsbDeployment.java
===================================================================
--- labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/metadata/EsbMetaData.java	2008-12-01 15:19:38 UTC (rev 24184)
+++ labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/metadata/EsbMetaData.java	2008-12-01 15:43:15 UTC (rev 24185)
@@ -28,9 +28,10 @@
  * Metadata for an ESB deployment consists of a {@link DeploymentUnit} and
  * an archive name.
  * <p/>
- * This metadata is intended by be created a a Deployment Parser. A parser
- * deployer could read an xml configuration file, or could be generated in some
- * other way, perhaps using annotations on class files, another language, etc.
+ * This metadata is intended by be created by a Deployment Parser. A deployment
+ * parser could read an xml configuration file, or it could gather the same
+ * information in another way, perhaps using annotations on class files, another
+ * language, etc.
  *
  * @author <a href="mailto:dbevenius at jboss.com">Daniel Bevenius</a>
  * @since 5.0




More information about the jboss-svn-commits mailing list
--- labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/deployers/EsbDeployment.java	2008-12-01 15:19:38 UTC (rev 24184)
+++ labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/deployers/EsbDeployment.java	2008-12-01 15:43:15 UTC (rev 24185)
@@ -27,9 +27,8 @@
 import org.jboss.esb.util.AssertArgument;
 
 /**
- * An EsbDeployment is a MicroContainer (MC) deployment that wraps
- * an ESB DeploymentUnit and implements MC lifecycle methods starting and
- * stopping an {@link EsbRuntimeDeployment}
+ * An EsbDeployment is a MicroContainer (MC) deployment that consists
+ * of an {@link DeploymentUnit}, and a {@link EsbRuntimeDeployment}.
  * <p/>
  * An EsbDeployment is created by the Microcontainer and the Microcontainer
  * is also responsible for the lifecycle events, like createing, starting, and stopping.
@@ -40,9 +39,9 @@
 public class EsbDeployment
 {
     /**
-     * The name of the achive.
+     * The name of the deployment achive.
      */
-    private String archiveName;
+    private String deploymentName;
 
     /**
      * The ESB DeploymentUnit. The collection of resouces, routers, and
@@ -58,14 +57,14 @@
     /**
      * Construct.
      *
      * @param archiveName       The name of the archive that this deployment came from.
      * @param deploymentUnit    The ESB DeploymentUnit that is to be deployed.
      */
-    public EsbDeployment(final String archiveName, final DeploymentUnit deploymentUnit)
+    public EsbDeployment(final String deploymentName, final DeploymentUnit deploymentUnit)
     {
-        AssertArgument.isNotNull(archiveName, "archiveName");
+        AssertArgument.isNotNull(deploymentName, "deploymentName");
         AssertArgument.isNotNull(deploymentUnit, "deploymentUnit");
-        this.archiveName = archiveName;
+        this.deploymentName = deploymentName;
         this.deploymentUnit = deploymentUnit;
     }
 
@@ -78,7 +77,7 @@
     {
         // TODO: Fix classloading..make it play nicely with MC. Daniel
         runtime = new DeploymentRuntime(new DeploymentUnitResourceLocator(getClass().getClassLoader()));
-        runtime.setDeploymentName(archiveName);
+        runtime.setDeploymentName(deploymentName);
         runtime.addDeploymentUnit(deploymentUnit);
     }
 
@@ -110,9 +109,9 @@
         return deploymentUnit;
     }
 
-    public String getArchiveName()
+    public String getDeploymentName()
     {
-        return archiveName;
+        return deploymentName;
     }
 
 }
@@ -58,14 +57,14 @@
      * Construct.
      *
-     * @param archiveName       The name of the archive that this deployment came from.
+     * @param deploymentName   The name of the archive that this deployment came from.
      * @param deploymentUnit    The ESB DeploymentUnit that is to be deployed.
      */

Modified: labs/jbossesb/workspace/skeagh/container/microcontainer/src/main/java/org/jboss/esb/microcontainer/metadata/EsbMetaData.java
===================================================================